===============
dteenergybridge
===============


.. image:: https://img.shields.io/pypi/v/dteenergybridge.svg
        :target: https://pypi.python.org/pypi/dteenergybridge

.. image:: https://img.shields.io/travis/kylehendricks/dteenergybridge.svg
        :target: https://travis-ci.org/kylehendricks/dteenergybridge

.. image:: https://pyup.io/repos/github/kylehendricks/dteenergybridge/shield.svg
     :target: https://pyup.io/repos/github/kylehendricks/dteenergybridge/
     :alt: Updates


Library for retrieving data from a DTE Energy Bridge


* Free software: MIT license


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

